import numpy as np
import numpy.ma as ma
import matplotlib as mpl
import matplotlib.pyplot as plt
import sys
import math
import matplotlib.pyplot as plt
from mpl_toolkits.axes_grid1.inset_locator import zoomed_inset_axes
from mpl_toolkits.axes_grid1.inset_locator import mark_inset
import mpl_toolkits.axisartist as AA
plt.switch_backend('agg')
mpl.rc('lines', linewidth=6)
mpl.rc('axes', linewidth=3)#


#---------------------------------------------------
def set_figure_sharex():
   fig = plt.figure(figsize=(12,12),dpi=fig_dpi)
   fig, axs = plt.subplots(3, 1, sharex=True)
   fig.subplots_adjust(left=0.25, wspace=0.15,bottom=0.,top=0.95,right=0.9)
   #gs = mpl.gridspec.GridSpec(1, 1, width_ratios=[1],height_ratios=[1.]) 
   #ax  = plt.subplot(gs[0])
   fig,ax = plt.subplots(2, 1, sharex=True,figsize=(12, 12))
   fig.subplots_adjust(hspace=0,left=0.25, wspace=0.15,bottom=0.24,top=0.95,right=0.9)
   ax[0].tick_params('both', labelsize=fs,pad=10,length=10, width=3, which='major')
   ax[1].tick_params('both', labelsize=fs,pad=10,length=10, width=3, which='major')
   return fig,ax


#---------------------------------------------------
def set_figure_inset():
   fig = plt.figure(figsize=(12,12),dpi=fig_dpi)
   fig.subplots_adjust(left=0.25, wspace=0.15,bottom=0.2,top=0.95,right=0.93)
   gs = mpl.gridspec.GridSpec(1, 1, width_ratios=[1],height_ratios=[1.]) 
   ax  = plt.subplot(gs[0])
   ax.tick_params('both', labelsize=fs,pad=10,length=10, width=3, which='major')
   return fig,ax


#---------------------------------------------------
def set_figure():
   fig = plt.figure(figsize=(12,12),dpi=fig_dpi)
   fig.subplots_adjust(left=0.25, wspace=0.15,bottom=0.2,top=0.95,right=0.95)
   gs = mpl.gridspec.GridSpec(1, 1, width_ratios=[1],height_ratios=[1.]) 
   ax  = plt.subplot(gs[0])
   ax.tick_params('both', labelsize=fs,pad=10,length=10, width=3, which='major')
   return fig,ax

    #---------------------------------------------------
    #---------------------------------------------------
     #---------------------------------------------------
def set_figure_legend():
    fig = plt.figure(figsize=(12*1.7,12*0.35))
    fig.subplots_adjust(left=0., wspace=0.,bottom=0.,top=1,right=1)
    gs = mpl.gridspec.GridSpec(1, 1, width_ratios=[1],height_ratios=[1.])
    ax  = plt.subplot(gs[0])
    ax.tick_params('both', labelsize=fs,pad=10,length=10, width=3, which='major')
    return fig,ax        


#---------------------------------------------------
def one_plot(ax,in_file,icol,scalex,scaley,lc,lw,lt,label):

    try:
        data=np.genfromtxt(in_file)
    except:
        print('not possible')
    else:
        d1=data[:,0]*scalex[1]-scalex[0]
        d2= data[:,icol]*scaley
        line=ax.plot(d1[::40], d2[::40], lt,color=lc,linewidth=lw,label=label)
        return line


#format of figures to be saved
#fig_form='.eps'
fig_form='.png'
fig_dpi=100


#font size
fs=48
fs2=36
fs3=fs

#line type

#line width
lw=4

#FEM ROZLISENI
r1 = 1651
r2 = 0
d=r2/r1

cmax=4
cmap = plt.cm.Blues_r
map2 = [cmap(i) for i in range(0,cmap.N,cmap.N//cmax)]

cmap = plt.cm.Reds_r
map1 = [cmap(i) for i in range(0,cmap.N,cmap.N//cmax)]

cmap = plt.cm.Greens_r
map3 = [cmap(i) for i in range(0,cmap.N,cmap.N//cmax)]

cmap = plt.cm.Greys_r
map4 = [cmap(i) for i in range(0,cmap.N,cmap.N//cmax)]

cmap = plt.cm.Purples_r
map5 = [cmap(i) for i in range(0,cmap.N,cmap.N//cmax)]

cols=map1+map2+map3+map4+map5

#---------------------------------------------
#panel a
fig,ax=set_figure()
ax.set_ylabel('power (GW)',fontsize=fs,labelpad=20)
ax.set_xlabel('time (Gyr)',fontsize=fs,labelpad=20)

#def one_plot(ax,in_file,icol,scalex,scaley,lc,lw,lt,label):
scalex=[0.,1.]
scaley=[1.]
icol=1

one_plot(ax,"e0.5_LL-evol-htide.dat",1,scalex,scaley,cols[3*cmax+2],3,'-',r"$e=0.5e_0$")
one_plot(ax,"e1_LL-evol-htide.dat",1,scalex,scaley,'k',3,'-',r"$e=e_0$")
one_plot(ax,"e2_LL-evol-htide.dat",1,scalex,scaley,cols[4*cmax+2],3,'-',r"$e=2e_0$")
one_plot(ax,"esin-0.25Gy_LL-evol-htide.dat",1,scalex,scaley,cols[0*cmax+2],3,'-',r"$T_{\rm per}=0.25$Gy")
one_plot(ax,"esin-1.0Gy_LL-evol-htide.dat",1,scalex,scaley,cols[0*cmax+0],3,'-',r"$T_{\rm per}=1$Gy")
line_rad=one_plot(ax,"LL-evol-hrad.dat",1,scalex,scaley,'darkgreen',3,'-',r"$radiogenic, LL")

handles, labels = ax.get_legend_handles_labels()

ax.set_xlim(left=0., right=4.51)
ticks=np.arange(0.,4.6,0.5)
plt.xticks(ticks,rotation=90)
ax.set_ylim(bottom=0,top=1800)

fig.legend(line_rad, ["radiogenic, LL"], loc='upper left',bbox_to_anchor=(0.25, 0.95, 0., 0.),fontsize=fs2,ncol=1,frameon=False,handletextpad=0.1)
#ax.legend(handles, labels,fontsize=fs3,ncol=1)
plt.savefig('panel-a'+fig_form,dpi=fig_dpi)
plt.close()

#-------------------------------------------
#panel b
fig,ax=set_figure_inset()
#ax[0].set_ylabel('melting rate (km/My)',fontsize=fs,labelpad=20)
ax.set_ylabel(r'melting rate (km/My)',fontsize=fs,labelpad=20)
ax.set_xlabel('time (Gyr)',fontsize=fs,labelpad=20)

scalex=[0.,1.]
scaley=[1.]
icol=1

one_plot(ax,"e0.5_LL-evol-crust-rate.dat",1,scalex,scaley,cols[3*cmax+2],3,'-',r"$e=0.5e_0$")
one_plot(ax,"e1_LL-evol-crust-rate.dat",1,scalex,scaley,'k',3,'-',r"$e=e_0$")
one_plot(ax,"e2_LL-evol-crust-rate.dat",1,scalex,scaley,cols[4*cmax+2],3,'-',r"$e=2e_0$")
one_plot(ax,"esin-0.25Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+2],3,'-',r"$T_{\rm per}=0.25$Gy")
one_plot(ax,"esin-1.0Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+0],3,'-',r"$T_{\rm per}=1$Gy")
ax.set_xlim(left=0., right=1.5)
plt.xticks(ticks,rotation=90)
plt.yticks(np.arange(0, 1.1, step=0.5))
ax.set_ylim(bottom=0,top=1.2)

axins = zoomed_inset_axes(ax, 3.1, loc=1, bbox_to_anchor=(0.,0.504,1.01,0.504), bbox_transform=ax.transAxes)
x1, x2, y1, y2 = 3.5, 4.5, 0.,0.16
axins.set_xlim(left=0., right=y2)
plt.yticks(np.arange(0, 0.16, step=0.05),fontsize=0.5*fs)
plt.xticks(np.arange(3.5, 4.49, step=0.5),fontsize=0.5*fs,rotation=90)

#inset with more details

axins.set_xlim(x1, x2)
axins.set_ylim(y1, y2)
one_plot(axins,"e0.5_LL-evol-crust-rate.dat",1,scalex,scaley,cols[3*cmax+2],3,'-',r"$e=0.5e_0$")
one_plot(axins,"e1_LL-evol-crust-rate.dat",1,scalex,scaley,'k',3,'-',r"$e=e_0$")
one_plot(axins,"e2_LL-evol-crust-rate.dat",1,scalex,scaley,cols[4*cmax+2],3,'-',r"$e=2e_0$")
one_plot(axins,"esin-0.125Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+3],3,'-',r"$T_{\rm per}=0.125$Gy, LL")
one_plot(axins,"esin-0.25Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+2],3,'-',r"$T_{\rm per}=0.25$Gy")
one_plot(axins,"esin-0.5Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+1],3,'-',r"$T_{\rm per}=0.5$Gy")
one_plot(axins,"esin-1.0Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+0],3,'-',r"$T_{\rm per}=1$Gy")
mark_inset(ax, axins, loc1=1, loc2=3, fc="none",lw=2,ec='0.5',)
plt.savefig('panel-b'+fig_form,dpi=fig_dpi)

plt.close()

#-------------------------------

fig,ax=set_figure_inset()
ax.set_ylabel(r'melting rate (km/My)',fontsize=fs,labelpad=20)
ax.set_xlabel('time (Gyr)',fontsize=fs,labelpad=20)

scalex=[0.,1.]
scaley=[1.]
icol=1

one_plot(ax,"esin-0.25Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+2],3,'-',r"LL, uniform")
one_plot(ax,"esin-0.25Gy_LL-part50-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+2],3,'--',r"LL, partitioning")
one_plot(ax,"esin-0.25Gy_CM-evol-crust-rate.dat",1,scalex,scaley,cols[1*cmax+2],3,'-',r"$CM, uniform")
one_plot(ax,"esin-0.25Gy_LL-part50-evol-crust-rate.dat",1,scalex,scaley,cols[1*cmax+2],3,'--',r"CM, partitioning")

ax.set_xlim(left=0., right=1.5)
plt.xticks(ticks,rotation=90)

plt.yticks(np.arange(0, 1.1, step=0.5))
ax.set_ylim(bottom=0,top=1.2)
axins = zoomed_inset_axes(ax, 3.1, loc=1, bbox_to_anchor=(0.,0.504,1.01,0.504), bbox_transform=ax.transAxes)


x1, x2, y1, y2 = 3.5, 4.5, 0.,0.16

axins.set_xlim(left=0., right=y2)
plt.yticks(np.arange(0, 0.15, step=0.05),fontsize=0.5*fs)
plt.xticks(np.arange(3.5, 4.49, step=0.5),fontsize=0.5*fs,rotation=90)

one_plot(axins,"esin-0.25Gy_LL-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+2],3,'-',r"LL, uniform")
one_plot(axins,"esin-0.25Gy_LL-part50-evol-crust-rate.dat",1,scalex,scaley,cols[0*cmax+2],3,'--',r"LL, partitioning")
one_plot(axins,"esin-0.25Gy_CM-evol-crust-rate.dat",1,scalex,scaley,cols[1*cmax+2],3,'-',r"$CM, uniform")
one_plot(axins,"esin-0.25Gy_LL-part50-evol-crust-rate.dat",1,scalex,scaley,cols[1*cmax+2],3,'--',r"CM, partitioning")

axins.set_xlim(x1, x2)
axins.set_ylim(y1, y2)

mark_inset(ax, axins, loc1=1,loc2=3, fc="none", lw=2, ec="0.5")

ex0,ey0=4.5,0.
ex1,ey1=4.5-0.5*0.25,0.04
ex2,ey2=4.5-0.25,0.0025
el0 = mpl.patches.Ellipse((ex0, ey0),0.1/4.5,0.17/4.5*0.15,angle=0,facecolor='w',edgecolor='k',linewidth=2.)
el1 = mpl.patches.Ellipse((ex1, ey1),0.1/4.5,0.17/4.5*0.15,angle=0,facecolor='w',edgecolor='k',linewidth=2.)
el2 = mpl.patches.Ellipse((ex2, ey2),0.1/4.5,0.17/4.5*0.15,angle=0,facecolor='w',edgecolor='k',linewidth=2.)
axins.annotate( '', xy=(ex0,ey0), xytext=(ex0,0.112), ha='center', \
  arrowprops=dict(arrowstyle="->",patchB=el0,lw=3),fontsize=fs2)
axins.annotate( '', xy=(ex1,ey1), xytext=(ex1,0.112), ha='center', \
            arrowprops=dict(arrowstyle="->",lw=3),fontsize=fs2)
axins.annotate( '', xy=(ex2,ey2), xytext=(ex2,0.112), ha='center', \
            arrowprops=dict(arrowstyle="->",lw=3),fontsize=fs2)

e0=0.0094
x=np.linspace(1.,4.5,1000)
ecc=e0*np.power(2.,np.sin(x*2*np.pi/0.25))
ecc0=e0*np.power(1.,np.sin(x*2*np.pi/0.25))
axt=axins.twinx()
line_ecc=axt.plot(x,ecc,'-',c='darkcyan',label='e',lw=3.)
axt.plot(x,ecc0,'--',c='darkcyan',label='e',lw=2.)
axt.set_ylim(bottom=-e0*2.5,top=e0*2.5)
ticks_major=[e0/2,e0,2*e0]
ticks_major_p=[r'$e_0/2$','$e_0$','$2e_0$']
axt.set_yticks(ticks_major)
axt.set_yticklabels(ticks_major_p,fontsize=fs*0.5,color='darkcyan')


axt.legend(line_ecc, ["eccentricity"], loc='upper left',bbox_to_anchor=(0.0, 1.075, 0., 0.),fontsize=fs*0.5,ncol=1,frameon=False,handletextpad=0.1)

line_w=axt.plot([0.],[0.],'-',c='white',label='none',lw=3.)

plt.savefig('panel-c'+fig_form,dpi=fig_dpi)
plt.close()


